# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2012 Canonical
# Author: Mirco "MacSlow" Müller <mirco.mueller@canonical.com>
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#

from compizconfig import Setting, Plugin
from time import sleep

from autopilot.globals import global_context
from autopilot.emulators.unity import get_state_by_path
from autopilot.emulators.X11 import Keyboard

import logging
logger = logging.getLogger(__name__)


class Spread(object):
    """
    An emulator class that makes it easier to interact with the spread of unity.
    """

    def __init__(self):
        self.plugin = Plugin(global_context, "unityshell")
        self.setting = Setting(self.plugin, "show_launcher")
        self._keyboard = Keyboard()
        super(Spread, self).__init__()

    def toggle_active(self):
        """
        Activates the spread if it is currently inactive, deactivates it otherwise.
        """
        logger.debug("Toggling spread with Super-W key-combo.")
        self._keyboard.press_and_release("^W")
        sleep(1)

    def ensure_active(self):
        """
        Ensures the dash is active.
        """
        if not self.get_is_active():
            self.toggle_active()

    def ensure_inactive(self):
        """
        Ensures the spread is not active.
        """
        if self.get_is_active():
            self.toggle_reveal()

    def get_is_active(self):
        """
        Is the spread active?
        """
        return bool(get_state_by_path("/Unity/DashController")[0]["spread"])
